==> apache-druid-0.22.0-src.tar.gz: apache-druid-0.22.0-src/server/src/main/java/org/apache/druid/curator/ZkEnablementConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.curator;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import org.apache.druid.java.util.common.StringUtils;

import java.util.Properties;

public class ZkEnablementConfig
{
  private static final String PROP_KEY_ENABLED = StringUtils.format("%s.enabled", CuratorModule.CURATOR_CONFIG_PREFIX);

  public static final ZkEnablementConfig ENABLED = new ZkEnablementConfig(true);

  @JsonProperty
  private final boolean enabled;

  @JsonCreator
  public ZkEnablementConfig(@JsonProperty("enabled") Boolean enabled)
  {
    this.enabled = enabled == null ? true : enabled.booleanValue();
  }

  public boolean isEnabled()
  {
    return enabled;
  }

  public static boolean isEnabled(Properties properties)
  {
    String value = properties.getProperty(PROP_KEY_ENABLED);
    return value == null ? true : Boolean.parseBoolean(value);
  }
}

==> apache-druid-25.0.0-src.tar.gz: apache-druid-25.0.0-src/server/src/main/java/org/apache/druid/curator/ZkEnablementConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.curator;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import org.apache.druid.java.util.common.StringUtils;

import java.util.Properties;

public class ZkEnablementConfig
{
  private static final String PROP_KEY_ENABLED = StringUtils.format("%s.enabled", CuratorConfig.CONFIG_PREFIX);

  public static final ZkEnablementConfig ENABLED = new ZkEnablementConfig(true);

  @JsonProperty
  private final boolean enabled;

  @JsonCreator
  public ZkEnablementConfig(@JsonProperty("enabled") Boolean enabled)
  {
    this.enabled = enabled == null ? true : enabled.booleanValue();
  }

  public boolean isEnabled()
  {
    return enabled;
  }

  public static boolean isEnabled(Properties properties)
  {
    String value = properties.getProperty(PROP_KEY_ENABLED);
    return value == null ? true : Boolean.parseBoolean(value);
  }
}
